@@ -84,7 +84,7 @@
 #define KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWINDOWSYSTEM_NO_DEPRECATED
-#  define KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56f00
+#  define KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57000
 #endif
 #ifdef KWINDOWSYSTEM_NO_DEPRECATED_WARNINGS
 #  define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE KWINDOWSYSTEM_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE 0x56f00
+#    define KWINDOWSYSTEM_DEPRECATED_WARNINGS_SINCE 0x57000
 #  endif
 #endif
 
